xmltest package
===============

Submodules
----------

xmltest.instance\_docs module
-----------------------------

.. automodule:: xmltest.instance_docs
   :members:
   :undoc-members:
   :show-inheritance:

xmltest.types module
--------------------

.. automodule:: xmltest.types
   :members:
   :undoc-members:
   :show-inheritance:

xmltest.validator module
------------------------

.. automodule:: xmltest.validator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: xmltest
   :members:
   :undoc-members:
   :show-inheritance:
